"use strict";

var _interopRequireDefault = require("reshow-runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _extends2 = _interopRequireDefault(require("reshow-runtime/helpers/extends"));

var _objectWithoutProperties2 = _interopRequireDefault(require("reshow-runtime/helpers/objectWithoutProperties"));

var _react = _interopRequireDefault(require("react"));

var _callFunc = _interopRequireDefault(require("call-func"));

var _getObjectValue = _interopRequireDefault(require("get-object-value"));

var _reactAtomicMolecule = require("react-atomic-molecule");

var isArray = Array.isArray;

var plusOne = function plusOne(i) {
  return i + 1;
};

var getFromTo = function getFromTo(from, to) {
  return plusOne(from) + '-' + plusOne(to);
};

var BasePage = function BasePage(props) {
  var onPageChange = props.onPageChange,
      component = props.component,
      className = props.className,
      children = props.children,
      style = props.style,
      url = props.url,
      rel = props.rel;
  var classes = (0, _reactAtomicMolecule.mixClass)((0, _getObjectValue["default"])(component, ['props', 'className']), className, 'item link');
  var onClick = onPageChange ? function () {
    return (0, _callFunc["default"])(onPageChange, [{
      begin: props[0],
      end: props[1],
      page: props['currentPage'],
      perPageNum: props['perPageNum']
    }]);
  } : null;
  return (0, _reactAtomicMolecule.build)(component)({
    rel: rel,
    title: getFromTo(props[0], props[1]),
    className: classes,
    href: url,
    style: style,
    onClick: onClick,
    'data-begin': props[0],
    'data-end': props[1],
    'data-page': props['currentPage'],
    'data-per-page-num': props['perPageNum']
  }, children);
};

var Page = function Page(props) {
  return _react["default"].createElement(BasePage, props, props.currentPage);
};

var Forward = function Forward(_ref) {
  var isLastPage = _ref.isLastPage,
      text = _ref.text,
      props = (0, _objectWithoutProperties2["default"])(_ref, ["isLastPage", "text"]);
  return _react["default"].createElement(BasePage, (0, _extends2["default"])({}, props, {
    style: {
      display: 'inline'
    },
    rel: "next"
  }), isLastPage ? props.currentPage : text);
};

var Backward = function Backward(_ref2) {
  var text = _ref2.text,
      props = (0, _objectWithoutProperties2["default"])(_ref2, ["text"]);
  return _react["default"].createElement(BasePage, (0, _extends2["default"])({}, props, {
    style: {
      display: 'inline'
    },
    rel: "prev"
  }), props.currentPage === 1 ? props.currentPage : text);
};

var Current = function Current(props) {
  return _react["default"].createElement(_reactAtomicMolecule.Item, {
    title: getFromTo(props[0], props[1]),
    className: "active",
    style: {
      display: 'inline'
    }
  }, props.currentPage);
};

var FirstPage = function FirstPage(props) {
  return _react["default"].createElement(Page, props);
};

var LastPage = function LastPage(props) {
  return _react["default"].createElement(Page, props);
};

var Ellipsis = function Ellipsis(props) {
  return _react["default"].createElement(_reactAtomicMolecule.Item, {
    className: "disabled ellipsis",
    style: {
      minWidth: 0,
      width: 0
    }
  }, "...");
};

var _ref3 =
/*#__PURE__*/
_react["default"].createElement(Ellipsis, null);

var _ref4 =
/*#__PURE__*/
_react["default"].createElement(Ellipsis, null);

var Pagination = function Pagination(pg) {
  injects = (0, _reactAtomicMolecule.lazyInject)(injects, InjectStyles);
  var linkComponent = pg.linkComponent,
      onPageChange = pg.onPageChange,
      forwardText = pg.forwardText,
      backwardText = pg.backwardText;
  var firstPage;
  var firstEllipsis;
  var lastPage;
  var lastEllipsis;

  if (pg.firstPage) {
    firstPage = _react["default"].createElement(FirstPage, (0, _extends2["default"])({}, pg.firstPage, {
      component: linkComponent,
      onPageChange: onPageChange
    }));
    firstEllipsis = _ref3;
  }

  if (pg.lastPage) {
    lastPage = _react["default"].createElement(LastPage, (0, _extends2["default"])({}, pg.lastPage, {
      component: linkComponent,
      onPageChange: onPageChange
    }));
    lastEllipsis = _ref4;
  }

  var pgList = pg.list;

  if (!isArray(pgList)) {
    console.error('Page list not array', pg);
  }

  return _react["default"].createElement(_reactAtomicMolecule.Menu, {
    className: "compact pagination"
  }, firstPage, firstEllipsis, pgList.map(function (v, k) {
    var current = pg.currentPage;

    if (v.currentPage) {
      if (current.backward && current.backward.currentPage === v.currentPage || current.forward && current.forward.currentPage === v.currentPage) {
        return null;
      }

      return _react["default"].createElement(Page, (0, _extends2["default"])({
        key: k
      }, v, {
        component: linkComponent,
        onPageChange: onPageChange
      }));
    } else {
      var re = [];

      if (current.backward) {
        re.push(_react["default"].createElement(Backward, (0, _extends2["default"])({
          text: backwardText
        }, current.backward, {
          component: linkComponent,
          onPageChange: onPageChange
        })));
      }

      re.push(_react["default"].createElement(Current, (0, _extends2["default"])({
        key: k
      }, current, {
        component: linkComponent,
        onPageChange: onPageChange
      })));

      if (current.forward) {
        re.push(_react["default"].createElement(Forward, (0, _extends2["default"])({
          isLastPage: pgList.length - 2 === k
        }, current.forward, {
          component: linkComponent,
          text: forwardText,
          onPageChange: onPageChange
        })));
      }

      return re;
    }
  }), lastEllipsis, lastPage);
};

Pagination.defaultProps = {
  linkComponent: 'a',
  forwardText: '> Next',
  backwardText: '<'
};
var _default = Pagination;
exports["default"] = _default;
var injects;
var pgCssSelector = '.pagination.ui.menu:not(.vertical) .item';
var InjectStyles = {
  hidePg: [{
    display: 'none',
    minWidth: '2rem',
    justifyContent: 'center'
  }, pgCssSelector],
  showPg: [{
    display: 'flex'
  }, [_reactAtomicMolecule.min.sm, pgCssSelector]]
};
module.exports = exports.default;