import _extends from "reshow-runtime/es/helpers/extends";
import _objectWithoutProperties from "reshow-runtime/es/helpers/objectWithoutProperties";
import React from 'react';
import callfunc from 'call-func';
import get from 'get-object-value';
import { build, min, mixClass, lazyInject, Item, Menu } from 'react-atomic-molecule';
var isArray = Array.isArray;

var plusOne = function plusOne(i) {
  return i + 1;
};

var getFromTo = function getFromTo(from, to) {
  return plusOne(from) + '-' + plusOne(to);
};

var BasePage = function BasePage(props) {
  var onPageChange = props.onPageChange,
      component = props.component,
      className = props.className,
      children = props.children,
      style = props.style,
      url = props.url,
      rel = props.rel;
  var classes = mixClass(get(component, ['props', 'className']), className, 'item link');
  var onClick = onPageChange ? function () {
    return callfunc(onPageChange, [{
      begin: props[0],
      end: props[1],
      page: props['currentPage'],
      perPageNum: props['perPageNum']
    }]);
  } : null;
  return build(component)({
    rel: rel,
    title: getFromTo(props[0], props[1]),
    className: classes,
    href: url,
    style: style,
    onClick: onClick,
    'data-begin': props[0],
    'data-end': props[1],
    'data-page': props['currentPage'],
    'data-per-page-num': props['perPageNum']
  }, children);
};

var Page = function Page(props) {
  return React.createElement(BasePage, props, props.currentPage);
};

var Forward = function Forward(_ref) {
  var isLastPage = _ref.isLastPage,
      text = _ref.text,
      props = _objectWithoutProperties(_ref, ["isLastPage", "text"]);

  return React.createElement(BasePage, _extends({}, props, {
    style: {
      display: 'inline'
    },
    rel: "next"
  }), isLastPage ? props.currentPage : text);
};

var Backward = function Backward(_ref2) {
  var text = _ref2.text,
      props = _objectWithoutProperties(_ref2, ["text"]);

  return React.createElement(BasePage, _extends({}, props, {
    style: {
      display: 'inline'
    },
    rel: "prev"
  }), props.currentPage === 1 ? props.currentPage : text);
};

var Current = function Current(props) {
  return React.createElement(Item, {
    title: getFromTo(props[0], props[1]),
    className: "active",
    style: {
      display: 'inline'
    }
  }, props.currentPage);
};

var FirstPage = function FirstPage(props) {
  return React.createElement(Page, props);
};

var LastPage = function LastPage(props) {
  return React.createElement(Page, props);
};

var Ellipsis = function Ellipsis(props) {
  return React.createElement(Item, {
    className: "disabled ellipsis",
    style: {
      minWidth: 0,
      width: 0
    }
  }, "...");
};

var _ref3 =
/*#__PURE__*/
React.createElement(Ellipsis, null);

var _ref4 =
/*#__PURE__*/
React.createElement(Ellipsis, null);

var Pagination = function Pagination(pg) {
  injects = lazyInject(injects, InjectStyles);
  var linkComponent = pg.linkComponent,
      onPageChange = pg.onPageChange,
      forwardText = pg.forwardText,
      backwardText = pg.backwardText;
  var firstPage;
  var firstEllipsis;
  var lastPage;
  var lastEllipsis;

  if (pg.firstPage) {
    firstPage = React.createElement(FirstPage, _extends({}, pg.firstPage, {
      component: linkComponent,
      onPageChange: onPageChange
    }));
    firstEllipsis = _ref3;
  }

  if (pg.lastPage) {
    lastPage = React.createElement(LastPage, _extends({}, pg.lastPage, {
      component: linkComponent,
      onPageChange: onPageChange
    }));
    lastEllipsis = _ref4;
  }

  var pgList = pg.list;

  if (!isArray(pgList)) {
    console.error('Page list not array', pg);
  }

  return React.createElement(Menu, {
    className: "compact pagination"
  }, firstPage, firstEllipsis, pgList.map(function (v, k) {
    var current = pg.currentPage;

    if (v.currentPage) {
      if (current.backward && current.backward.currentPage === v.currentPage || current.forward && current.forward.currentPage === v.currentPage) {
        return null;
      }

      return React.createElement(Page, _extends({
        key: k
      }, v, {
        component: linkComponent,
        onPageChange: onPageChange
      }));
    } else {
      var re = [];

      if (current.backward) {
        re.push(React.createElement(Backward, _extends({
          text: backwardText
        }, current.backward, {
          component: linkComponent,
          onPageChange: onPageChange
        })));
      }

      re.push(React.createElement(Current, _extends({
        key: k
      }, current, {
        component: linkComponent,
        onPageChange: onPageChange
      })));

      if (current.forward) {
        re.push(React.createElement(Forward, _extends({
          isLastPage: pgList.length - 2 === k
        }, current.forward, {
          component: linkComponent,
          text: forwardText,
          onPageChange: onPageChange
        })));
      }

      return re;
    }
  }), lastEllipsis, lastPage);
};

Pagination.defaultProps = {
  linkComponent: 'a',
  forwardText: '> Next',
  backwardText: '<'
};
export default Pagination;
var injects;
var pgCssSelector = '.pagination.ui.menu:not(.vertical) .item';
var InjectStyles = {
  hidePg: [{
    display: 'none',
    minWidth: '2rem',
    justifyContent: 'center'
  }, pgCssSelector],
  showPg: [{
    display: 'flex'
  }, [min.sm, pgCssSelector]]
};